==> knowledge-center-api-0.3.8-sources.jar: cn/yoofans/knowledge/center/api/dto/UserPlaybackProgressDTO.java <==
package cn.yoofans.knowledge.center.api.dto;

import cn.yoofans.knowledge.center.api.enums.course.UserCourseFinishState;

import java.io.Serializable;
import java.util.Date;

public class UserPlaybackProgressDTO implements Serializable {

    private static final long serialVersionUID = 3129876319508061866L;

    private Long id;

    private Long consumerId;

    private Long columnId;

    private Long courseId;

    private Integer playbackProgress;

    private Date gmtCreate;

    private Date gmtModified;

    private Long readId;

    /**
     * 完课状态
     * @see UserCourseFinishState
     */
    private Integer finishState;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getColumnId() {
        return columnId;
    }

    public void setColumnId(Long columnId) {
        this.columnId = columnId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Integer getPlaybackProgress() {
        return playbackProgress;
    }

    public void setPlaybackProgress(Integer playbackProgress) {
        this.playbackProgress = playbackProgress;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Integer getFinishState() {
        return finishState;
    }

    public void setFinishState(Integer finishState) {
        this.finishState = finishState;
    }
}

==> knowledge-center-api-0.3.9-20180911.060754-9-sources.jar: cn/yoofans/knowledge/center/api/dto/UserPlaybackProgressDTO.java <==
package cn.yoofans.knowledge.center.api.dto;

import cn.yoofans.knowledge.center.api.enums.course.UserCourseFinishState;
import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

public class UserPlaybackProgressDTO implements Serializable {

    private static final long serialVersionUID = 3129876319508061866L;

    private Long id;

    private Long consumerId;

    private Long columnId;

    private Long courseId;

    private Integer playbackProgress;

    private Date gmtCreate;

    private Date gmtModified;

    private Long readId;

    /**
     * 完课状态
     * @see UserCourseFinishState
     */
    private Integer finishState;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getColumnId() {
        return columnId;
    }

    public void setColumnId(Long columnId) {
        this.columnId = columnId;
    }

    public Long getCourseId() {
        return courseId;
    }

    public void setCourseId(Long courseId) {
        this.courseId = courseId;
    }

    public Integer getPlaybackProgress() {
        return playbackProgress;
    }

    public void setPlaybackProgress(Integer playbackProgress) {
        this.playbackProgress = playbackProgress;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getReadId() {
        return readId;
    }

    public void setReadId(Long readId) {
        this.readId = readId;
    }

    public Integer getFinishState() {
        return finishState;
    }

    public void setFinishState(Integer finishState) {
        this.finishState = finishState;
    }
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
